@@ -3,7 +3,7 @@ package App::mirai;
 use strict;
 use warnings;
 
-our $VERSION = '0.002';
+our $VERSION = '0.003';
 
 =encoding UTF-8
 
@@ -13,10 +13,13 @@ App::mirai - debugging for L<Future>-based code
 
 =head1 VERSION
 
-Version 0.002
+version 0.003
 
 =head1 SYNOPSIS
 
+ # Just trace a single script to STDOUT/STDERR:
+ mirai-trace script.pl
+
  # Run the Tickit interface, and have it load the script as a separate process, directing
  # STDOUT/STDERR to windows in the UI and communicating via pipepair
  mirai script.pl
@@ -283,4 +286,4 @@ Tom Molesworth <cpan@perlsite.co.uk>
 
 =head1 LICENSE
 
-Copyright Tom Molesworth 2014. Licensed under the same terms as Perl itself.
+Copyright Tom Molesworth 2014-2015. Licensed under the same terms as Perl itself.
