@@ -1,5 +1,5 @@
 package App::mirai::Future;
-$App::mirai::Future::VERSION = '0.002';
+$App::mirai::Future::VERSION = '0.003';
 use strict;
 use warnings;
 
@@ -9,7 +9,7 @@ App::mirai::Future - injects debugging code into L<Future>
 
 =head1 VERSION
 
-Version 0.002
+version 0.003
 
 =head1 DESCRIPTION
 
@@ -169,7 +169,7 @@ BEGIN {
 		$FUTURE_MAP{$name} = $entry;
 
 		# Yes, this means we're modifying the callback list: if we later
-		# add suppoort for debugging the callbacks as well, we'd need to
+		# add support for debugging the callbacks as well, we'd need to
 		# take this into account.
 		$f->on_ready(sub {
 			my $f = shift;
@@ -205,7 +205,8 @@ BEGIN {
 				$prep->($f);
 				# hahaha
 				my ($sub) = (caller 1)[3];
-				unless($sub && $sub eq 'Future::_new_dependent') {
+				# no, seriously?
+				unless($sub && ($sub eq 'Future::_new_dependent' or $sub eq 'Future::_new_convergent')) {
 					$_->invoke_event(create => $f) for grep defined, @WATCHERS;
 				}
 				$f
@@ -232,6 +233,8 @@ BEGIN {
 			};
 		},
 	);
+	# Changed in Future 0.30, I believe
+	$map{_new_convergent} = $map{_new_dependent};
 
 	for my $k (keys %map) {
 		my $orig = Future->can($k);
@@ -254,4 +257,4 @@ Tom Molesworth <cpan@perlsite.co.uk>
 
 =head1 LICENSE
 
-Copyright Tom Molesworth 2014. Licensed under the same terms as Perl itself.
+Copyright Tom Molesworth 2014-2015. Licensed under the same terms as Perl itself.
